@@ -339,7 +339,7 @@ void KeyCache::addFileSystemWatcher(const std::shared_ptr<FileSystemWatcher> &wa
     connect(watcher.get(), &FileSystemWatcher::fileChanged,
             this, [this]() { startKeyListing(); });
 
-    watcher->setEnabled(d->m_refreshJob == nullptr);
+    watcher->setEnabled(d->m_refreshJob.isNull());
 }
 
 void KeyCache::Private::refreshJobDone(const KeyListResult &result)
@@ -1143,7 +1143,7 @@ Error KeyCache::RefreshKeysJob::Private::startKeyListing(GpgME::Protocol proto)
 #if 0
     aheinecke: 2017.01.12:
 
-    For unkown reasons the new style connect fails at runtime
+    For unknown reasons the new style connect fails at runtime
     over library borders into QGpgME from the GpgME repo
     when cross compiled for Windows and default arguments
     are used in the Signal.
@@ -1220,9 +1220,9 @@ std::vector<GpgME::Key> KeyCache::findBestByMailBox(const char *addr, GpgME::Pro
         return ret;
     }
     if (proto == Protocol::OpenPGP) {
-        // Groups take precendece over autmatic keys. We return all here
+        // Groups take precedence over automatic keys. We return all here
         // so if a group key for example is expired we can show that.
-        ret = getGroupKeys(addr);
+        ret = getGroupKeys(QString::fromUtf8(addr));
         if (!ret.empty()) {
             return ret;
         }
@@ -1236,7 +1236,7 @@ std::vector<GpgME::Key> KeyCache::findBestByMailBox(const char *addr, GpgME::Pro
         if (needEncrypt && !k.canEncrypt()) {
             continue;
         }
-        if (needSign && !k.canSign()) {
+        if (needSign && (!k.canSign() || !k.hasSecret())) {
             continue;
         }
         /* First get the uid that matches the mailbox */
@@ -1254,7 +1254,7 @@ std::vector<GpgME::Key> KeyCache::findBestByMailBox(const char *addr, GpgME::Pro
             } else if (uidC.validity() == u.validity() && uidIsOk(u)) {
                 /* Both are the same check which one is newer. */
                 time_t oldTime = 0;
-                for (const Subkey s: keyC.subkeys()) {
+                for (const Subkey &s: keyC.subkeys()) {
                     if (!subkeyIsOk(s)) {
                         continue;
                     }
@@ -1267,7 +1267,7 @@ std::vector<GpgME::Key> KeyCache::findBestByMailBox(const char *addr, GpgME::Pro
                     }
                 }
                 time_t newTime = 0;
-                for (const Subkey s: k.subkeys()) {
+                for (const Subkey &s: k.subkeys()) {
                     if (!subkeyIsOk(s)) {
                         continue;
                     }
