@@ -97,13 +97,13 @@ public:
 
     QString fingerprint() const;
     /** Set the key by fingerprint. Starts a background KeyListJob to
-        retrive the complete GpgME::Key object
+        retrieve the complete GpgME::Key object
     */
     void setFingerprint(const QString &fingerprint);
 
     QStringList fingerprints() const;
     /** Set the keys by fingerprint. Starts a background KeyListJob to
-        retrive the complete GpgME::Key objects
+        retrieve the complete GpgME::Key objects
     */
     void setFingerprints(const QStringList &fingerprints);
 
@@ -143,11 +143,11 @@ private Q_SLOTS:
     void slotEraseButtonClicked();
 
 private:
-    const QGpgME::Protocol *mOpenPGPBackend;
-    const QGpgME::Protocol *mSMIMEBackend;
-    QLabel *mLabel;
-    QPushButton *mEraseButton;
-    QPushButton *mDialogButton;
+    const QGpgME::Protocol *mOpenPGPBackend = nullptr;
+    const QGpgME::Protocol *mSMIMEBackend = nullptr;
+    QLabel *mLabel = nullptr;
+    QPushButton *mEraseButton = nullptr;
+    QPushButton *mDialogButton = nullptr;
     QString mDialogCaption, mDialogMessage, mInitialQuery;
     bool mMulti;
     unsigned int mKeyUsage;
